module W.Styles exposing (globalStyles, baseTheme)

{-| You will need both globalStyles and a theme to get started with elm-widgets.

    view : List (Html msg)
    view =
        [ W.Styles.globalStyles
        , W.Styles.baseTheme

        -- ... your application views
        ]


# Custom Themes

elm-widgets is fully compatible with [elm-theme](https://package.elm-lang.org/packages/uncover-co/elm-theme/latest/). So you can use that package to create and expose new themes to your application.

e.g. This would create a dark-mode ready application based on the user system's settings.

    import Theme
    import W.Styles

    view : List (Html msg)
    view =
        [ W.Styles.globalStyles
        , Theme.globalProviderWithDarkMode
            { light = Theme.lightTheme
            , dark = Theme.darkTheme
            , strategy = Theme.systemStrategy
            }

        -- ... your application views
        ]


# API

@docs globalStyles, baseTheme

-}

import Html as H
import Theme


{-| -}
baseTheme : H.Html msg
baseTheme =
    Theme.globalProvider Theme.lightTheme


{-| -}
globalStyles : H.Html msg
globalStyles =
    H.node "style"
        []
        [ H.text """*,:after,:before{--tw-border-spacing-x:0;--tw-border-spacing-y:0;--tw-translate-x:0;--tw-translate-y:0;--tw-rotate:0;--tw-skew-x:0;--tw-skew-y:0;--tw-scale-x:1;--tw-scale-y:1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness:proximity;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width:0px;--tw-ring-offset-color:#fff;--tw-ring-color:rgba(59,130,246,.5);--tw-ring-offset-shadow:0 0 #0000;--tw-ring-shadow:0 0 #0000;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }::backdrop{--tw-border-spacing-x:0;--tw-border-spacing-y:0;--tw-translate-x:0;--tw-translate-y:0;--tw-rotate:0;--tw-skew-x:0;--tw-skew-y:0;--tw-scale-x:1;--tw-scale-y:1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness:proximity;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width:0px;--tw-ring-offset-color:#fff;--tw-ring-color:rgba(59,130,246,.5);--tw-ring-offset-shadow:0 0 #0000;--tw-ring-shadow:0 0 #0000;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }.ew-btn{align-items:center;box-sizing:border-box;display:inline-flex;font-family:var(--theme-font-text);font-weight:600;justify-content:center;letter-spacing:.05em;line-height:1;padding-bottom:0;padding-top:0;position:relative;text-decoration-line:none}.ew-btn:before{--tw-content:"";background-color:transparent;bottom:0;content:var(--tw-content);display:block;left:0;pointer-events:none;position:absolute;right:0;top:0;transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);z-index:0}.ew-btn:hover:before{background-color:rgba(0,0,0,.1);content:var(--tw-content)}.ew-btn-like{-webkit-appearance:none;-moz-appearance:none;appearance:none;border-radius:8px;border-width:0;box-sizing:border-box;text-decoration-line:none}.ew-radio{--tw-bg-opacity:1;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;--tw-ring-color:rgb(var(--theme-primary-fg-ch)/0.5);--tw-ring-offset-width:0px;align-items:center;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity));border-color:rgb(var(--theme-base-aux-ch)/.3);border-style:solid;border-width:2px;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow);display:inline-flex;height:1.75rem;justify-content:center;margin:0;outline:2px solid transparent;outline-offset:2px;width:1.75rem}.ew-radio,.ew-radio:before{transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-radio:before{--tw-content:"";--tw-scale-x:0;--tw-scale-y:0;background-color:currentColor;content:var(--tw-content);display:block;height:1rem;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));transition-timing-function:cubic-bezier(0,0,.2,1);width:1rem}.ew-radio:hover{opacity:.9}.ew-radio:active{opacity:.75}.ew-radio:checked,.ew-radio:focus{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity))}.ew-radio:focus-visible{--tw-border-opacity:1;--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity));box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-radio:checked:before{--tw-scale-x:1;--tw-scale-y:1;content:var(--tw-content);transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-radio:disabled{background-color:rgb(var(--theme-base-aux-ch)/.25)}.ew-radio.ew-small{-webkit-appearance:none;-moz-appearance:none;appearance:none;height:1.25rem;width:1.25rem}.ew-radio.ew-small:before{content:var(--tw-content);height:.625rem;width:.625rem}.ew-checkbox{--tw-bg-opacity:1;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;--tw-ring-color:rgb(var(--theme-primary-fg-ch)/0.5);--tw-ring-offset-width:0px;align-items:center;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity));border-color:rgb(var(--theme-base-aux-ch)/.3);border-style:solid;border-width:2px;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow);display:inline-flex;justify-content:center;margin:0;outline:2px solid transparent;outline-offset:2px}.ew-checkbox,.ew-checkbox:before{height:1.75rem;width:1.75rem}.ew-checkbox:before{--tw-content:"";content:var(--tw-content);display:none}.ew-checkbox:hover{opacity:.9}.ew-checkbox:active{opacity:.75}.ew-checkbox:checked{background-color:currentColor;border-width:0}.ew-checkbox:checked:before{content:var(--tw-content);display:block}.ew-checkbox:disabled{background-color:rgb(var(--theme-base-aux-ch)/.25)}.ew-checkbox:focus{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity))}.ew-checkbox:focus-visible{--tw-border-opacity:1;--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity));box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-checkbox.ew-small{-webkit-appearance:none;-moz-appearance:none;appearance:none;height:1.25rem;width:1.25rem}.ew-checkbox.ew-small:before{content:var(--tw-content);height:1.25rem;width:1.25rem}.ew-checkbox.ew-colorful{border-color:currentColor}.ew-toggle{--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;--tw-ring-color:rgb(var(--theme-primary-fg-ch)/0.5);--tw-ring-offset-width:0px;align-items:center;-webkit-appearance:none;-moz-appearance:none;appearance:none;border-width:2px;box-sizing:content-box;display:inline-flex;justify-content:flex-start;margin:0;outline:2px solid transparent;outline-offset:2px;padding:.125rem;width:2.75rem}.ew-toggle,.ew-toggle:before{border-radius:9999px;border-style:solid;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow);transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-toggle:before{--tw-content:"";--tw-shadow:0 1px 3px 0 rgba(0,0,0,.1),0 1px 2px -1px rgba(0,0,0,.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color),0 1px 2px -1px var(--tw-shadow-color);--tw-bg-opacity:1;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity));border-color:rgb(var(--theme-base-aux-ch)/.3);border-width:1px;display:block;height:1.25rem;transition-timing-function:cubic-bezier(0,0,.2,1);width:1.25rem}.ew-toggle:hover{opacity:.9}.ew-toggle:active{opacity:.75}.ew-toggle{background-color:rgb(var(--theme-base-aux-ch)/.2);border-color:rgb(var(--theme-base-aux-ch)/.3)}.ew-toggle:checked{background-color:currentColor;border-color:rgb(var(--theme-base-bg-ch)/.3)}.ew-toggle:before{--tw-translate-x:0px}.ew-toggle:before,.ew-toggle:checked:before{content:var(--tw-content);transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-toggle:checked:before{--tw-translate-x:100%}.ew-toggle:focus-visible{--tw-border-opacity:1;--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity));box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-toggle:disabled{background-color:rgb(var(--theme-base-aux-ch)/.25)}.ew-toggle.ew-small{width:2.25rem}.ew-toggle.ew-small:before{content:var(--tw-content);height:1rem;width:1rem}.ew-pointer-events-none{pointer-events:none}.ew-pointer-events-auto{pointer-events:auto}.ew-visible{visibility:visible}.ew-fixed{position:fixed}.ew-absolute{position:absolute}.ew-relative{position:relative}.ew-sticky{position:sticky}.ew-inset-0{bottom:0;left:0;right:0;top:0}.ew-inset-1{bottom:.25rem;left:.25rem;right:.25rem;top:.25rem}.ew-inset-4{bottom:1rem;left:1rem;right:1rem;top:1rem}.ew-inset-y-0{bottom:0;top:0}.ew-inset-x-\\[12px\\]{left:12px;right:12px}.ew-inset-x-0{left:0;right:0}.ew-inset-x-2{left:.5rem;right:.5rem}.ew-inset-y-1{bottom:.25rem;top:.25rem}.ew-inset-x-1{left:.25rem;right:.25rem}.ew-inset-x-3{left:.75rem;right:.75rem}.ew-inset-y-3{bottom:.75rem;top:.75rem}.ew-bottom-full{bottom:100%}.ew-left-full{left:100%}.ew-top-full{top:100%}.ew-left-0{left:0}.ew-right-0{right:0}.ew-top-1\\/2{top:50%}.-ew-top-px{top:-1px}.ew-left-9{left:2.25rem}.ew-top-0{top:0}.ew-left-8{left:2rem}.ew-top-2{top:.5rem}.ew-right-2{right:.5rem}.ew-top-4{top:1rem}.ew-right-4{right:1rem}.-ew-left-1{left:-.25rem}.ew-bottom-0{bottom:0}.ew-top-1{top:.25rem}.ew-right-1{right:.25rem}.ew-left-1{left:.25rem}.ew-right-3{right:.75rem}.-ew-top-2{top:-.5rem}.ew-bottom-2{bottom:.5rem}.ew-left-4{left:1rem}.ew-left-3{left:.75rem}.ew-bottom-4{bottom:1rem}.ew-bottom-3{bottom:.75rem}.ew-bottom-1{bottom:.25rem}.ew-bottom-auto{bottom:auto}.-ew-top-4{top:-1rem}.-ew-left-4{left:-1rem}.-ew-left-2{left:-.5rem}.ew-top-8{top:2rem}.ew-top-6{top:1.5rem}.ew-left-12{left:3rem}.ew-left-10{left:2.5rem}.ew-right-full{right:100%}.ew-top-\\[28px\\]{top:28px}.ew-z-10{z-index:10}.ew-z-0{z-index:0}.ew-z-\\[9999\\]{z-index:9999}.ew-z-20{z-index:20}.ew-col-span-12{grid-column:span 12/span 12}.ew-col-span-11{grid-column:span 11/span 11}.ew-col-span-9{grid-column:span 9/span 9}.ew-col-span-8{grid-column:span 8/span 8}.ew-col-span-7{grid-column:span 7/span 7}.ew-col-span-6{grid-column:span 6/span 6}.ew-col-span-5{grid-column:span 5/span 5}.ew-col-span-4{grid-column:span 4/span 4}.ew-col-span-3{grid-column:span 3/span 3}.ew-col-span-2{grid-column:span 2/span 2}.ew-col-span-1{grid-column:span 1/span 1}.ew-m-0{margin:0}.ew-m-auto{margin:auto}.ew-m-5{margin:1.25rem}.ew-m-4{margin:1rem}.-ew-mx-px{margin-left:-1px;margin-right:-1px}.ew-mx-auto{margin-left:auto;margin-right:auto}.-ew-mb-2\\.5{margin-bottom:-.625rem}.-ew-ml-2\\.5{margin-left:-.625rem}.-ew-mb-2{margin-bottom:-.5rem}.-ew-ml-2{margin-left:-.5rem}.ew-mt-2{margin-top:.5rem}.-ew-mt-0\\.5{margin-top:-.125rem}.-ew-mt-0{margin-top:0}.-ew-mt-\\[3px\\]{margin-top:-3px}.-ew-ml-5{margin-left:-1.25rem}.-ew-mt-5{margin-top:-1.25rem}.-ew-mb-1{margin-bottom:-.25rem}.-ew-ml-1{margin-left:-.25rem}.-ew-ml-4{margin-left:-1rem}.-ew-mt-4{margin-top:-1rem}.-ew-mt-3{margin-top:-.75rem}.-ew-ml-3{margin-left:-.75rem}.-ew-ml-6{margin-left:-1.5rem}.-ew-mt-6{margin-top:-1.5rem}.ew-mb-2{margin-bottom:.5rem}.ew-mb-1{margin-bottom:.25rem}.ew-mt-1{margin-top:.25rem}.ew-mr-1{margin-right:.25rem}.ew-ml-1{margin-left:.25rem}.ew-box-border{box-sizing:border-box}.ew-block{display:block}.ew-inline-block{display:inline-block}.ew-flex{display:flex}.ew-inline-flex{display:inline-flex}.ew-table{display:table}.ew-grid{display:grid}.ew-hidden{display:none}.ew-h-6{height:1.5rem}.ew-h-4{height:1rem}.ew-h-\\[32px\\]{height:32px}.ew-h-\\[40px\\]{height:40px}.ew-h-\\[48px\\]{height:48px}.ew-h-0{height:0}.ew-h-14{height:3.5rem}.ew-h-8{height:2rem}.ew-h-1{height:.25rem}.ew-h-\\[6px\\]{height:6px}.ew-h-12{height:3rem}.ew-h-full{height:100%}.ew-h-px{height:1px}.ew-h-10{height:2.5rem}.ew-h-16{height:4rem}.ew-h-24{height:6rem}.ew-h-32{height:8rem}.ew-h-20{height:5rem}.ew-h-2{height:.5rem}.ew-h-fit{height:-moz-fit-content;height:fit-content}.ew-h-9{height:2.25rem}.ew-h-7{height:1.75rem}.ew-h-5{height:1.25rem}.ew-h-\\[20px\\]{height:20px}.ew-h-1\\.5{height:.375rem}.ew-max-h-64{max-height:16rem}.ew-min-h-\\[50px\\]{min-height:50px}.ew-min-h-\\[48px\\]{min-height:48px}.ew-min-h-\\[60px\\]{min-height:60px}.ew-min-h-min{min-height:-moz-min-content;min-height:min-content}.ew-min-h-\\[32px\\]{min-height:32px}.ew-w-full{width:100%}.ew-w-10{width:2.5rem}.ew-w-8{width:2rem}.ew-w-\\[40\\%\\]{width:40%}.ew-w-\\[60\\%\\]{width:60%}.ew-w-0{width:0}.ew-w-1{width:.25rem}.ew-w-4{width:1rem}.ew-w-2{width:.5rem}.ew-w-6{width:1.5rem}.ew-w-12{width:3rem}.ew-w-fit{width:-moz-fit-content;width:fit-content}.ew-w-max{width:-moz-max-content;width:max-content}.ew-w-1\\.5{width:.375rem}.ew-min-w-\\[32px\\]{min-width:32px}.ew-min-w-\\[40px\\]{min-width:40px}.ew-min-w-\\[48px\\]{min-width:48px}.ew-min-w-full{min-width:100%}.ew-max-w-full{max-width:100%}.ew-max-w-md{max-width:28rem}.ew-max-w-lg{max-width:32rem}.ew-max-w-xl{max-width:36rem}.ew-shrink-0{flex-shrink:0}.ew-grow{flex-grow:1}.ew-table-fixed{table-layout:fixed}.ew-translate-y-0{--tw-translate-y:0px}.-ew-translate-y-0,.ew-translate-y-0{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.-ew-translate-y-0{--tw-translate-y:-0px}.-ew-translate-y-1{--tw-translate-y:-0.25rem}.-ew-translate-y-1,.ew-translate-x-0{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-translate-x-0{--tw-translate-x:0px}.-ew-translate-x-0{--tw-translate-x:-0px}.-ew-translate-x-0,.ew-translate-y-1{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-translate-y-1{--tw-translate-y:0.25rem}.-ew-translate-x-2{--tw-translate-x:-0.5rem}.-ew-translate-x-2,.ew-translate-x-1{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-translate-x-1{--tw-translate-x:0.25rem}.ew-translate-y-0\\.5{--tw-translate-y:0.125rem}.-ew-translate-y-0\\.5,.ew-translate-y-0\\.5{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.-ew-translate-y-0\\.5{--tw-translate-y:-0.125rem}.-ew-translate-y-1\\/2{--tw-translate-y:-50%}.-ew-translate-y-1\\/2,.ew-translate-x-0\\.5{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-translate-x-0\\.5{--tw-translate-x:0.125rem}.-ew-translate-x-0\\.5{--tw-translate-x:-0.125rem}.-ew-translate-x-0\\.5,.ew-rotate-\\[45deg\\]{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-rotate-\\[45deg\\]{--tw-rotate:45deg}.ew-scale-0{--tw-scale-x:0;--tw-scale-y:0}.ew-scale-0,.ew-scale-100{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-scale-100{--tw-scale-x:1;--tw-scale-y:1}.ew-scale-90{--tw-scale-x:.9;--tw-scale-y:.9;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}@keyframes ew-ew-animation-fade-slide{0%{opacity:0;transform:translateY(10px) scale(.9)}to{opacity:1;transform:translateY(0) scale(1)}}.ew-animate-fade-slide{animation:ew-ew-animation-fade-slide .4s ease-out}@keyframes ew-pulse{50%{opacity:.5}}.ew-animate-pulse{animation:ew-pulse 2s cubic-bezier(.4,0,.6,1) infinite}.ew-cursor-default{cursor:default}.ew-cursor-text{cursor:text}.ew-list-none{list-style-type:none}.ew-appearance-none{-webkit-appearance:none;-moz-appearance:none;appearance:none}.ew-grid-cols-1{grid-template-columns:repeat(1,minmax(0,1fr))}.ew-grid-cols-12{grid-template-columns:repeat(12,minmax(0,1fr))}.ew-flex-row{flex-direction:row}.ew-flex-col{flex-direction:column}.ew-flex-wrap{flex-wrap:wrap}.ew-place-content-center{place-content:center}.ew-place-items-center{place-items:center}.ew-content-center{align-content:center}.ew-content-start{align-content:flex-start}.ew-items-start{align-items:flex-start}.ew-items-end{align-items:flex-end}.ew-items-center{align-items:center}.ew-items-baseline{align-items:baseline}.ew-items-stretch{align-items:stretch}.ew-justify-start{justify-content:flex-start}.ew-justify-end{justify-content:flex-end}.ew-justify-center{justify-content:center}.ew-justify-between{justify-content:space-between}.ew-justify-around{justify-content:space-around}.ew-justify-items-stretch{justify-items:stretch}.ew-gap-2{gap:.5rem}.ew-gap-3{gap:.75rem}.ew-gap-4{gap:1rem}.ew-gap-0{gap:0}.ew-gap-1{gap:.25rem}.ew-gap-6{gap:1.5rem}.ew-gap-8{gap:2rem}.ew-gap-12{gap:3rem}.ew-gap-16{gap:4rem}.ew-gap-1\\.5{gap:.375rem}.ew-gap-px{gap:1px}.ew-gap-5{gap:1.25rem}.ew-space-x-2>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(.5rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(.5rem*var(--tw-space-x-reverse))}.ew-space-x-0>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(0px*(1 - var(--tw-space-x-reverse)));margin-right:calc(0px*var(--tw-space-x-reverse))}.ew-space-x-1>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(.25rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(.25rem*var(--tw-space-x-reverse))}.ew-space-x-4>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(1rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(1rem*var(--tw-space-x-reverse))}.ew-space-x-6>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(1.5rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(1.5rem*var(--tw-space-x-reverse))}.ew-space-x-8>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(2rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(2rem*var(--tw-space-x-reverse))}.ew-space-x-12>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(3rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(3rem*var(--tw-space-x-reverse))}.ew-space-x-16>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(4rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(4rem*var(--tw-space-x-reverse))}.ew-space-y-0>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(0px*var(--tw-space-y-reverse));margin-top:calc(0px*(1 - var(--tw-space-y-reverse)))}.ew-space-y-1>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(.25rem*var(--tw-space-y-reverse));margin-top:calc(.25rem*(1 - var(--tw-space-y-reverse)))}.ew-space-y-2>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(.5rem*var(--tw-space-y-reverse));margin-top:calc(.5rem*(1 - var(--tw-space-y-reverse)))}.ew-space-y-4>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(1rem*var(--tw-space-y-reverse));margin-top:calc(1rem*(1 - var(--tw-space-y-reverse)))}.ew-space-y-6>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(1.5rem*var(--tw-space-y-reverse));margin-top:calc(1.5rem*(1 - var(--tw-space-y-reverse)))}.ew-space-y-8>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(2rem*var(--tw-space-y-reverse));margin-top:calc(2rem*(1 - var(--tw-space-y-reverse)))}.ew-space-y-12>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(3rem*var(--tw-space-y-reverse));margin-top:calc(3rem*(1 - var(--tw-space-y-reverse)))}.ew-space-y-16>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(4rem*var(--tw-space-y-reverse));margin-top:calc(4rem*(1 - var(--tw-space-y-reverse)))}.ew--space-x-2>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-left:calc(-.5rem*(1 - var(--tw-space-x-reverse)));margin-right:calc(-.5rem*var(--tw-space-x-reverse))}.ew-self-end{align-self:flex-end}.ew-self-stretch{align-self:stretch}.ew-overflow-auto{overflow:auto}.ew-overflow-hidden{overflow:hidden}.ew-overflow-visible{overflow:visible}.ew-overflow-y-auto{overflow-y:auto}.ew-overflow-x-hidden{overflow-x:hidden}.ew-overflow-x-visible{overflow-x:visible}.ew-overflow-y-visible{overflow-y:visible}.ew-overflow-y-scroll{overflow-y:scroll}.ew-overscroll-contain{overscroll-behavior:contain}.ew-whitespace-pre-wrap{white-space:pre-wrap}.ew-break-words{overflow-wrap:break-word}.ew-rounded-full{border-radius:9999px}.ew-rounded-lg{border-radius:8px}.ew-rounded-\\[20px\\]{border-radius:20px}.ew-rounded-\\[16px\\]{border-radius:16px}.ew-rounded{border-radius:4px}.ew-rounded-md{border-radius:6px}.ew-rounded-sm{border-radius:2px}.ew-rounded-xl{border-radius:12px}.ew-rounded-t{border-top-left-radius:4px;border-top-right-radius:4px}.ew-border-0{border-width:0}.ew-border-\\[3px\\]{border-width:3px}.ew-border-2{border-width:2px}.ew-border{border-width:1px}.ew-border-y{border-bottom-width:1px;border-top-width:1px}.ew-border-t-2{border-top-width:2px}.ew-border-l-2{border-left-width:2px}.ew-border-l-\\[6px\\]{border-left-width:6px}.ew-border-t{border-top-width:1px}.ew-border-l{border-left-width:1px}.ew-border-l-0{border-left-width:0}.ew-border-r-0{border-right-width:0}.ew-border-l-4{border-left-width:4px}.ew-border-b{border-bottom-width:1px}.ew-border-r{border-right-width:1px}.ew-border-t-4{border-top-width:4px}.ew-border-t-8{border-top-width:8px}.ew-border-solid{border-style:solid}.ew-border-none{border-style:none}.ew-border-primary-fg{--tw-border-opacity:1;border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity))}.ew-border-neutral-fg{--tw-border-opacity:1;border-color:rgb(var(--theme-neutral-fg-ch)/var(--tw-border-opacity))}.ew-border-base-aux\\/30{border-color:rgb(var(--theme-base-aux-ch)/.3)}.ew-border-current{border-color:currentColor}.ew-border-base-aux\\/10{border-color:rgb(var(--theme-base-aux-ch)/.1)}.ew-border-base-aux\\/20{border-color:rgb(var(--theme-base-aux-ch)/.2)}.ew-border-base-aux{--tw-border-opacity:1;border-color:rgb(var(--theme-base-aux-ch)/var(--tw-border-opacity))}.ew-border-base-bg{--tw-border-opacity:1;border-color:rgb(var(--theme-base-bg-ch)/var(--tw-border-opacity))}.ew-border-white{--tw-border-opacity:1;border-color:rgb(255 255 255/var(--tw-border-opacity))}.ew-border-base-fg{--tw-border-opacity:1;border-color:rgb(var(--theme-base-fg-ch)/var(--tw-border-opacity))}.ew-border-opacity-50{--tw-border-opacity:0.5}.ew-border-opacity-30{--tw-border-opacity:0.3}.ew-bg-transparent{background-color:transparent}.ew-bg-primary-bg{--tw-bg-opacity:1;background-color:rgb(var(--theme-primary-bg-ch)/var(--tw-bg-opacity))}.ew-bg-neutral-bg{--tw-bg-opacity:1;background-color:rgb(var(--theme-neutral-bg-ch)/var(--tw-bg-opacity))}.ew-bg-primary-fg\\/\\[0\\.1\\]{background-color:rgb(var(--theme-primary-fg-ch)/.1)}.ew-bg-neutral-fg\\/\\[0\\.07\\]{background-color:rgb(var(--theme-neutral-fg-ch)/.07)}.ew-bg-base-bg{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity))}.ew-bg-white{--tw-bg-opacity:1;background-color:rgb(255 255 255/var(--tw-bg-opacity))}.ew-bg-base-aux\\/30{background-color:rgb(var(--theme-base-aux-ch)/.3)}.ew-bg-current{background-color:currentColor}.ew-bg-base-aux\\/\\[0\\.07\\]{background-color:rgb(var(--theme-base-aux-ch)/.07)}.ew-bg-primary-fg\\/10{background-color:rgb(var(--theme-primary-fg-ch)/.1)}.ew-bg-black\\/30{background-color:rgba(0,0,0,.3)}.ew-bg-base-aux{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-aux-ch)/var(--tw-bg-opacity))}.ew-bg-primary-fg{--tw-bg-opacity:1;background-color:rgb(var(--theme-primary-fg-ch)/var(--tw-bg-opacity))}.ew-bg-black{--tw-bg-opacity:1;background-color:rgb(0 0 0/var(--tw-bg-opacity))}.ew-bg-neutral-aux{--tw-bg-opacity:1;background-color:rgb(var(--theme-neutral-aux-ch)/var(--tw-bg-opacity))}.ew-bg-danger-fg{--tw-bg-opacity:1;background-color:rgb(var(--theme-danger-fg-ch)/var(--tw-bg-opacity))}.ew-bg-warning-fg{--tw-bg-opacity:1;background-color:rgb(var(--theme-warning-fg-ch)/var(--tw-bg-opacity))}.ew-bg-success-fg{--tw-bg-opacity:1;background-color:rgb(var(--theme-success-fg-ch)/var(--tw-bg-opacity))}.ew-bg-base-fg{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-fg-ch)/var(--tw-bg-opacity))}.ew-bg-danger-bg{--tw-bg-opacity:1;background-color:rgb(var(--theme-danger-bg-ch)/var(--tw-bg-opacity))}.ew-bg-yellow-300{--tw-bg-opacity:1;background-color:rgb(253 224 71/var(--tw-bg-opacity))}.ew-bg-yellow-500{--tw-bg-opacity:1;background-color:rgb(234 179 8/var(--tw-bg-opacity))}.ew-bg-neutral-fg{--tw-bg-opacity:1;background-color:rgb(var(--theme-neutral-fg-ch)/var(--tw-bg-opacity))}.ew-bg-yellow-200{--tw-bg-opacity:1;background-color:rgb(254 240 138/var(--tw-bg-opacity))}.ew-bg-base-aux\\/10{background-color:rgb(var(--theme-base-aux-ch)/.1)}.ew-p-0{padding:0}.ew-p-1{padding:.25rem}.ew-p-2{padding:.5rem}.ew-p-3{padding:.75rem}.ew-p-4{padding:1rem}.ew-p-6{padding:1.5rem}.ew-p-8{padding:2rem}.ew-p-12{padding:3rem}.ew-p-16{padding:4rem}.ew-p-5{padding:1.25rem}.ew-p-px{padding:1px}.ew-px-2\\.5{padding-left:.625rem;padding-right:.625rem}.ew-px-2{padding-left:.5rem;padding-right:.5rem}.ew-px-1\\.5{padding-left:.375rem;padding-right:.375rem}.ew-px-1{padding-left:.25rem;padding-right:.25rem}.ew-py-0{padding-bottom:0;padding-top:0}.ew-px-3{padding-left:.75rem;padding-right:.75rem}.ew-px-5{padding-left:1.25rem;padding-right:1.25rem}.ew-px-6{padding-left:1.5rem;padding-right:1.5rem}.ew-px-4{padding-left:1rem;padding-right:1rem}.ew-px-0{padding-left:0;padding-right:0}.ew-px-8{padding-left:2rem;padding-right:2rem}.ew-px-12{padding-left:3rem;padding-right:3rem}.ew-px-16{padding-left:4rem;padding-right:4rem}.ew-py-1{padding-bottom:.25rem;padding-top:.25rem}.ew-py-2{padding-bottom:.5rem;padding-top:.5rem}.ew-py-3{padding-bottom:.75rem;padding-top:.75rem}.ew-py-4{padding-bottom:1rem;padding-top:1rem}.ew-py-6{padding-bottom:1.5rem;padding-top:1.5rem}.ew-py-8{padding-bottom:2rem;padding-top:2rem}.ew-py-12{padding-bottom:3rem;padding-top:3rem}.ew-py-16{padding-bottom:4rem;padding-top:4rem}.ew-px-px{padding-left:1px;padding-right:1px}.ew-py-px{padding-bottom:1px;padding-top:1px}.ew-pt-0{padding-top:0}.ew-pt-1{padding-top:.25rem}.ew-pt-2{padding-top:.5rem}.ew-pt-3{padding-top:.75rem}.ew-pt-4{padding-top:1rem}.ew-pt-6{padding-top:1.5rem}.ew-pt-8{padding-top:2rem}.ew-pt-12{padding-top:3rem}.ew-pt-16{padding-top:4rem}.ew-pl-0{padding-left:0}.ew-pl-1{padding-left:.25rem}.ew-pl-2{padding-left:.5rem}.ew-pl-3{padding-left:.75rem}.ew-pl-4{padding-left:1rem}.ew-pl-6{padding-left:1.5rem}.ew-pl-8{padding-left:2rem}.ew-pl-12{padding-left:3rem}.ew-pl-16{padding-left:4rem}.ew-pr-0{padding-right:0}.ew-pr-1{padding-right:.25rem}.ew-pr-2{padding-right:.5rem}.ew-pr-3{padding-right:.75rem}.ew-pr-4{padding-right:1rem}.ew-pr-6{padding-right:1.5rem}.ew-pr-8{padding-right:2rem}.ew-pr-12{padding-right:3rem}.ew-pr-16{padding-right:4rem}.ew-pb-0{padding-bottom:0}.ew-pb-1{padding-bottom:.25rem}.ew-pb-2{padding-bottom:.5rem}.ew-pb-3{padding-bottom:.75rem}.ew-pb-4{padding-bottom:1rem}.ew-pb-6{padding-bottom:1.5rem}.ew-pb-8{padding-bottom:2rem}.ew-pb-12{padding-bottom:3rem}.ew-pb-16{padding-bottom:4rem}.ew-pt-0\\.5{padding-top:.125rem}.ew-pr-10{padding-right:2.5rem}.ew-pt-\\[10px\\]{padding-top:10px}.ew-pt-3\\.5{padding-top:.875rem}.ew-pt-64{padding-top:16rem}.ew-pt-5{padding-top:1.25rem}.ew-pr-24{padding-right:6rem}.ew-pb-5{padding-bottom:1.25rem}.ew-pt-px{padding-top:1px}.ew-pl-px{padding-left:1px}.ew-pr-px{padding-right:1px}.ew-pb-24{padding-bottom:6rem}.ew-text-left{text-align:left}.ew-text-center{text-align:center}.ew-text-right{text-align:right}.ew-indent-0{text-indent:0}.ew-font-text{font-family:var(--theme-font-text)}.ew-font-heading{font-family:var(--theme-font-heading)}.ew-text-sm{font-size:.875rem;line-height:1.25rem}.ew-text-xs{font-size:.75rem;line-height:1rem}.ew-text-base{font-size:1rem;line-height:1.5rem}.ew-text-2xl{font-size:1.5rem;line-height:2rem}.ew-text-lg{font-size:1.125rem;line-height:1.75rem}.ew-text-xl{font-size:1.25rem;line-height:1.75rem}.ew-text-4xl{font-size:2.25rem;line-height:2.5rem}.ew-text-5xl{font-size:3rem;line-height:1}.ew-text-3xl{font-size:1.875rem;line-height:2.25rem}.ew-font-semibold{font-weight:600}.ew-font-medium{font-weight:500}.ew-font-normal{font-weight:400}.ew-font-bold{font-weight:700}.ew-font-light{font-weight:300}.ew-uppercase{text-transform:uppercase}.ew-italic{font-style:italic}.ew-leading-none{line-height:1}.ew-leading-relaxed{line-height:1.625}.ew-tracking-wider{letter-spacing:.05em}.ew-text-primary-aux{--tw-text-opacity:1;color:rgb(var(--theme-primary-aux-ch)/var(--tw-text-opacity))}.ew-text-neutral-aux{--tw-text-opacity:1;color:rgb(var(--theme-neutral-aux-ch)/var(--tw-text-opacity))}.ew-text-primary-fg{--tw-text-opacity:1;color:rgb(var(--theme-primary-fg-ch)/var(--tw-text-opacity))}.ew-text-neutral-fg{--tw-text-opacity:1;color:rgb(var(--theme-neutral-fg-ch)/var(--tw-text-opacity))}.ew-text-base-fg{--tw-text-opacity:1;color:rgb(var(--theme-base-fg-ch)/var(--tw-text-opacity))}.ew-text-base-aux{--tw-text-opacity:1;color:rgb(var(--theme-base-aux-ch)/var(--tw-text-opacity))}.ew-text-base-aux\\/80{color:rgb(var(--theme-base-aux-ch)/.8)}.ew-text-inherit{color:inherit}.ew-text-transparent{color:transparent}.ew-text-danger-fg{--tw-text-opacity:1;color:rgb(var(--theme-danger-fg-ch)/var(--tw-text-opacity))}.ew-text-warning-fg{--tw-text-opacity:1;color:rgb(var(--theme-warning-fg-ch)/var(--tw-text-opacity))}.ew-text-success-fg{--tw-text-opacity:1;color:rgb(var(--theme-success-fg-ch)/var(--tw-text-opacity))}.ew-text-base-bg{--tw-text-opacity:1;color:rgb(var(--theme-base-bg-ch)/var(--tw-text-opacity))}.ew-text-danger-aux{--tw-text-opacity:1;color:rgb(var(--theme-danger-aux-ch)/var(--tw-text-opacity))}.ew-text-neutral-bg{--tw-text-opacity:1;color:rgb(var(--theme-neutral-bg-ch)/var(--tw-text-opacity))}.ew-underline{text-decoration-line:underline}.ew-line-through{text-decoration-line:line-through}.ew-no-underline{text-decoration-line:none}.ew-placeholder-base-aux::-moz-placeholder{--tw-placeholder-opacity:1;color:rgb(var(--theme-base-aux-ch)/var(--tw-placeholder-opacity))}.ew-placeholder-base-aux::placeholder{--tw-placeholder-opacity:1;color:rgb(var(--theme-base-aux-ch)/var(--tw-placeholder-opacity))}.ew-placeholder-base-aux\\/80::-moz-placeholder{color:rgb(var(--theme-base-aux-ch)/.8)}.ew-placeholder-base-aux\\/80::placeholder{color:rgb(var(--theme-base-aux-ch)/.8)}.ew-opacity-0{opacity:0}.ew-opacity-\\[0\\.60\\]{opacity:.6}.ew-opacity-50{opacity:.5}.ew-opacity-20{opacity:.2}.ew-opacity-80{opacity:.8}.ew-opacity-40{opacity:.4}.ew-opacity-30{opacity:.3}.ew-opacity-60{opacity:.6}.ew-opacity-100{opacity:1}.ew-shadow{--tw-shadow:0 1px 3px 0 rgba(0,0,0,.1),0 1px 2px -1px rgba(0,0,0,.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color),0 1px 2px -1px var(--tw-shadow-color)}.ew-shadow,.ew-shadow-lg{box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.ew-shadow-lg{--tw-shadow:0 10px 15px -3px rgba(0,0,0,.1),0 4px 6px -4px rgba(0,0,0,.1);--tw-shadow-colored:0 10px 15px -3px var(--tw-shadow-color),0 4px 6px -4px var(--tw-shadow-color)}.ew-shadow-none{--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000}.ew-shadow-md,.ew-shadow-none{box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.ew-shadow-md{--tw-shadow:0 4px 6px -1px rgba(0,0,0,.1),0 2px 4px -2px rgba(0,0,0,.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color),0 2px 4px -2px var(--tw-shadow-color)}.ew-shadow-xl{--tw-shadow:0 20px 25px -5px rgba(0,0,0,.1),0 8px 10px -6px rgba(0,0,0,.1);--tw-shadow-colored:0 20px 25px -5px var(--tw-shadow-color),0 8px 10px -6px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.ew-shadow-black{--tw-shadow-color:#000;--tw-shadow:var(--tw-shadow-colored)}.ew-outline-none{outline:2px solid transparent;outline-offset:2px}.ew-outline-0{outline-width:0}.ew-outline-primary-fg{outline-color:rgb(var(--theme-primary-fg-ch))}.ew-ring-2{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color)}.ew-ring,.ew-ring-2{box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-ring{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color)}.ew-ring-0{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-ring-primary-fg\\/50{--tw-ring-color:rgb(var(--theme-primary-fg-ch)/0.5)}.ew-ring-primary-fg{--tw-ring-opacity:1;--tw-ring-color:rgb(var(--theme-primary-fg-ch)/var(--tw-ring-opacity))}.ew-ring-offset-0{--tw-ring-offset-width:0px}.ew-blur{--tw-blur:blur(8px);filter:var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)}.ew-backdrop-blur-sm{--tw-backdrop-blur:blur(4px)}.ew-backdrop-blur,.ew-backdrop-blur-sm{-webkit-backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia);backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia)}.ew-backdrop-blur{--tw-backdrop-blur:blur(8px)}.ew-transition{transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-transition-transform{transition-duration:.15s;transition-property:transform;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-transition-shadow{transition-duration:.15s;transition-property:box-shadow;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-delay-500{transition-delay:.5s}.ew-delay-1000{transition-delay:1s}.ew-duration-300{transition-duration:.3s}.ew-focusable,.ew-focusable-reset{--tw-ring-color:rgb(var(--theme-primary-fg-ch)/0.5);--tw-ring-offset-width:0px;outline:2px solid transparent;outline-offset:2px}.ew-focusable{transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-focusable:focus-visible{--tw-border-opacity:1;--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity));box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-focusable-inset{--tw-ring-inset:inset;--tw-ring-color:rgb(var(--theme-primary-fg-ch)/0.5);outline:2px solid transparent;outline-offset:2px;transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-focusable-inset:focus-visible{--tw-border-opacity:1;--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity));box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-focusable-outline{--tw-ring-color:rgb(var(--theme-primary-fg-ch)/0.5);--tw-ring-offset-width:0px;outline:2px solid transparent;outline-offset:2px;transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1)}.ew-focusable-outline:focus-visible{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.ew-relative-background:before{bottom:0;content:" ";display:block;left:0;position:absolute;right:0;top:0}.ew-justify-stretch>*{flex-grow:1;flex-shrink:0}input[type=color].ew-input-color::-webkit-color-swatch,input[type=color].ew-input-color::-webkit-color-swatch-wrapper{display:none}.ew-input-icon{display:none}.ew-input select option{background-color:var(--theme-base-bg);color:var(--theme-base-fg)}.ew-input input+.ew-input-icon:before,.ew-input select+.ew-input-icon:before{background:rgb(var(--theme-base-aux-ch)/.07)}.ew-input input:focus+.ew-input-icon:before,.ew-input select:focus+.ew-input-icon:before{background:var(--theme-base-bg)}.ew-input input:disabled+.ew-input-icon:before,.ew-input select:disabled+.ew-input-icon:before{background:rgb(var(--theme-base-aux-ch)/.3)}.ew-input input[aria-readonly]:disabled+.ew-input-icon:before,.ew-input select[aria-readonly]:disabled+.ew-input-icon:before{background:rgb(var(--theme-base-aux-ch)/.07)}.ew-input input[aria-readonly]:-moz-read-only:focus+.ew-input-icon:before,.ew-input select[aria-readonly]:-moz-read-only:focus+.ew-input-icon:before{background:rgb(var(--theme-base-aux-ch)/.1)}.ew-input input[aria-readonly]:read-only:focus+.ew-input-icon:before,.ew-input select[aria-readonly]:read-only:focus+.ew-input-icon:before{background:rgb(var(--theme-base-aux-ch)/.1)}.ew-input-autocomplete--options{display:none}.ew-input-autocomplete:focus-within+.ew-input-autocomplete--options{display:block}.ew-input-autocomplete--options:active{display:block}input[type=range].ew-slider{-webkit-appearance:none;background:transparent;height:auto;left:0;margin:0;opacity:1;outline:initial;position:relative;right:0;width:100%;z-index:0}input[type=range].ew-slider:disabled{pointer-events:none}input[type=range].ew-slider::-webkit-slider-runnable-track{background:initial;cursor:auto}input[type=range].ew-slider::-moz-range-track{background:initial;cursor:auto}input[type=range].ew-slider::-ms-track{background:initial;cursor:auto}input[type=range].ew-slider::-webkit-slider-thumb{-webkit-appearance:none;appearance:none;background:currentColor;border:2px solid #fff;border-radius:50%;box-shadow:0 0 4px rgba(0,0,0,.1);height:24px;-webkit-transition:.12s ease-in;transition:.12s ease-in;width:24px}input[type=range].ew-slider:hover::-webkit-slider-thumb{box-shadow:0 0 4px rgba(0,0,0,.1),0 0 4px currentColor}input[type=range].ew-slider:active::-webkit-slider-thumb{box-shadow:0 0 4px rgba(0,0,0,.1),0 0 2px currentColor;-webkit-transition:none;transition:none}input[type=range].ew-slider:focus-visible::-webkit-slider-thumb{box-shadow:0 0 4px rgba(0,0,0,.1),0 0 4px currentColor}input[type=range].ew-slider::-moz-range-thumb{-moz-appearance:none;appearance:none;background:currentColor;border:2px solid #fff;border-radius:50%;box-shadow:0 0 4px rgba(0,0,0,.1);height:24px;-moz-transition:.12s ease-in;transition:.12s ease-in;width:24px}input[type=range].ew-slider:hover::-moz-range-thumb{box-shadow:0 0 4px rgba(0,0,0,.1),0 0 4px currentColor}input[type=range].ew-slider:active::-moz-range-thumb{box-shadow:0 0 4px rgba(0,0,0,.1),0 0 2px currentColor;-moz-transition:none;transition:none}input[type=range].ew-slider:focus-visible::-moz-range-thumb{box-shadow:0 0 4px rgba(0,0,0,.1),0 0 4px currentColor}.ew-popover-content{display:none}.ew-popover-trigger:focus-within+.ew-popover-content{animation:ew-animation-fade .2s forwards;display:block}.ew-popover.ew-is-open>.ew-popover-content{animation:ew-animation-fade .2s forwards;display:block}.ew-popover.ew-is-closed .ew-popover-trigger:focus-within+.ew-popover-content{display:none}.ew-popover.ew-persistent:focus-within>.ew-popover-content{display:block}.ew-popover.ew-show-on-hover .ew-popover-trigger:hover+.ew-popover-content{animation:ew-animation-fade .2s forwards;display:block}.ew-popover.ew-show-on-hover>.ew-popover-content:hover{display:block}.ew-popover-content:active{display:block!important}.ew-modal-toggle:checked+.ew-modal,.ew-modal.ew-modal--is-open{display:block;opacity:1}.ew-modal-toggle:checked+.ew-modal>.ew-modal-content,.ew-modal.ew-modal--is-open>.ew-modal-content{animation:ew-animation-fade-slide-scale .2s ease-out forwards}.ew-checkbox:before{background-image:linear-gradient(-45deg,transparent 65%,currentColor 65.99%),linear-gradient(45deg,transparent 75%,currentColor 75.99%),linear-gradient(-45deg,currentColor 40%,transparent 40.99%),linear-gradient(45deg,currentColor 30%,var(--fg-color) 30.99%,var(--fg-color) 40%,transparent 40.99%),linear-gradient(-45deg,var(--fg-color) 50%,currentColor 50.99%)}.ew-checkbox:disabled:before{opacity:.4}.ew-tooltip:after{border-style:solid;content:"";display:block;position:absolute}.ew-tooltip.ew-tooltip-top:after{border-color:var(--theme-neutral-bg) transparent transparent transparent;border-width:4px 4px 0;left:50%;margin-left:-2px;top:100%}.ew-tooltip.ew-tooltip-bottom:after{border-color:transparent transparent var(--theme-neutral-bg) transparent;border-width:0 4px 4px;bottom:100%;left:50%;margin-left:-2px}.ew-tooltip.ew-tooltip-left:after{border-color:transparent transparent transparent var(--theme-neutral-bg);border-width:4px 0 4px 4px;left:100%;margin-top:-2px;top:50%}.ew-tooltip.ew-tooltip-right:after{border-color:transparent var(--theme-neutral-bg) transparent transparent;border-width:4px 4px 4px 0;margin-top:-2px;right:100%;top:50%}.ew-table,.ew-table tbody,.ew-table td,.ew-table th,.ew-table thead,.ew-table tr{border:0;border-collapse:collapse;margin:0;padding:0}.ew-table tr{border-bottom:1px solid rgb(var(--theme-base-aux-ch)/.2)}.ew-table thead{border-bottom:2px solid rgb(var(--theme-base-aux-ch)/.2)}.ew-table tbody tr:last-child{border-bottom:0}.ew-table td,.ew-table th{padding:12px 6px}.ew-table td:first-child,.ew-table th:first-child{padding-left:12px}.ew-table td:last-child,.ew-table th:last-child{padding-right:12px}.ew-table-group-header td{padding:16px 6px}@keyframes ew-animation-fade{0%{opacity:0}to{opacity:1}}@keyframes ew-animation-fade-slide{0%{opacity:0;transform:translateY(10px)}to{opacity:1;transform:translateY(0)}}@keyframes ew-animation-fade-slide-scale{0%{opacity:0;transform:translateY(10px) scale(.9)}to{opacity:1;transform:translateY(0) scale(1)}}.ew-loading-dots{display:inline-block;height:var(--size);position:relative;width:var(--size)}.ew-loading-dots div{animation-timing-function:cubic-bezier(0,1,1,0);background:var(--color);border-radius:calc(var(--size)*.2);height:calc(var(--size)*.2);position:absolute;top:calc(var(--size)*.4);width:calc(var(--size)*.2)}.ew-loading-dots>div:first-child{animation:ew-loading-dots-1 .6s infinite;left:0}.ew-loading-dots>div:nth-child(2){animation:ew-loading-dots-2 .6s infinite;left:0}.ew-loading-dots>div:nth-child(3){animation:ew-loading-dots-2 .6s infinite;left:calc(var(--size)*.4)}.ew-loading-dots>div:nth-child(4){animation:ew-loading-dots-3 .6s infinite;left:calc(var(--size)*.8)}@keyframes ew-loading-dots-1{0%{transform:scale(0)}to{transform:scale(1)}}@keyframes ew-loading-dots-2{0%{transform:translate(0)}to{transform:translate(calc(var(--size)*.4))}}@keyframes ew-loading-dots-3{0%{transform:scale(1)}to{transform:scale(0)}}.ew-loading-ripples{display:inline-block;height:var(--size);position:relative;width:var(--size)}.ew-loading-ripples>div{animation:ew-loading-ripples 1.2s cubic-bezier(0,.2,.8,1) infinite;border:calc(var(--size)*.06) solid var(--color);border-radius:50%;opacity:1;position:absolute}.ew-loading-ripples>div:nth-child(2){animation-delay:-.6s}@keyframes ew-loading-ripples{0%{height:0;left:calc(var(--size)*.5);opacity:1;top:calc(var(--size)*.5);width:0}to{height:var(--size);left:0;opacity:0;top:0;width:var(--size)}}.before\\:ew-pointer-events-none:before{content:var(--tw-content);pointer-events:none}.before\\:ew-absolute:before{content:var(--tw-content);position:absolute}.before\\:ew-inset-0:before{bottom:0;content:var(--tw-content);left:0;right:0;top:0}.before\\:ew-inset-1:before{bottom:.25rem;content:var(--tw-content);left:.25rem;right:.25rem;top:.25rem}.before\\:ew-z-0:before{content:var(--tw-content);z-index:0}.before\\:ew-block:before{content:var(--tw-content);display:block}.before\\:ew-h-0\\.5:before{content:var(--tw-content);height:.125rem}.before\\:ew-h-0:before{content:var(--tw-content);height:0}.before\\:ew-w-0\\.5:before{content:var(--tw-content);width:.125rem}.before\\:ew-w-0:before{content:var(--tw-content);width:0}.before\\:ew-grow:before{content:var(--tw-content);flex-grow:1}.before\\:ew-rounded-lg:before{border-radius:8px;content:var(--tw-content)}.before\\:ew-rounded:before{border-radius:4px;content:var(--tw-content)}.before\\:ew-rounded-\\[20px\\]:before{border-radius:20px;content:var(--tw-content)}.before\\:ew-rounded-\\[18px\\]:before{border-radius:18px;content:var(--tw-content)}.before\\:ew-rounded-\\[16px\\]:before{border-radius:16px;content:var(--tw-content)}.before\\:ew-rounded-\\[14px\\]:before{border-radius:14px;content:var(--tw-content)}.before\\:ew-rounded-sm:before{border-radius:2px;content:var(--tw-content)}.before\\:ew-rounded-full:before{border-radius:9999px;content:var(--tw-content)}.before\\:ew-rounded-r:before{border-bottom-right-radius:4px;border-top-right-radius:4px;content:var(--tw-content)}.before\\:ew-bg-current:before{background-color:currentColor;content:var(--tw-content)}.before\\:ew-bg-primary-aux:before{--tw-bg-opacity:1;background-color:rgb(var(--theme-primary-aux-ch)/var(--tw-bg-opacity));content:var(--tw-content)}.before\\:ew-bg-neutral-aux:before{--tw-bg-opacity:1;background-color:rgb(var(--theme-neutral-aux-ch)/var(--tw-bg-opacity));content:var(--tw-content)}.before\\:ew-bg-primary-fg:before{--tw-bg-opacity:1;background-color:rgb(var(--theme-primary-fg-ch)/var(--tw-bg-opacity));content:var(--tw-content)}.before\\:ew-bg-neutral-fg:before{--tw-bg-opacity:1;background-color:rgb(var(--theme-neutral-fg-ch)/var(--tw-bg-opacity));content:var(--tw-content)}.before\\:ew-opacity-0:before{content:var(--tw-content);opacity:0}.before\\:ew-opacity-\\[0\\.07\\]:before{content:var(--tw-content);opacity:.07}.before\\:ew-opacity-10:before{content:var(--tw-content);opacity:.1}.before\\:ew-transition:before{content:var(--tw-content);transition-duration:.15s;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1)}.before\\:ew-duration-200:before{content:var(--tw-content);transition-duration:.2s}.before\\:ew-content-\\[\\'\\'\\]:before{--tw-content:"";content:var(--tw-content)}.after\\:ew-absolute:after{content:var(--tw-content);position:absolute}.after\\:ew-inset-x-0:after{content:var(--tw-content);left:0;right:0}.after\\:ew-top-0:after{content:var(--tw-content);top:0}.after\\:ew-block:after{content:var(--tw-content);display:block}.after\\:ew-h-0\\.5:after{content:var(--tw-content);height:.125rem}.after\\:ew-h-0:after{content:var(--tw-content);height:0}.after\\:ew-h-1\\.5:after{content:var(--tw-content);height:.375rem}.after\\:ew-h-1:after{content:var(--tw-content);height:.25rem}.after\\:ew-w-0\\.5:after{content:var(--tw-content);width:.125rem}.after\\:ew-w-0:after{content:var(--tw-content);width:0}.after\\:ew-grow:after{content:var(--tw-content);flex-grow:1}.after\\:ew-rounded-t:after{border-top-left-radius:4px;border-top-right-radius:4px;content:var(--tw-content)}.after\\:ew-bg-current:after{background-color:currentColor;content:var(--tw-content)}.after\\:ew-content-\\[\\'\\'\\]:after{--tw-content:"";content:var(--tw-content)}.first\\:ew-ml-0:first-child{margin-left:0}.first\\:ew-rounded-l-lg:first-child{border-bottom-left-radius:8px;border-top-left-radius:8px}.first\\:ew-rounded-l-\\[16px\\]:first-child{border-bottom-left-radius:16px;border-top-left-radius:16px}.first\\:ew-rounded-l-\\[20px\\]:first-child{border-bottom-left-radius:20px;border-top-left-radius:20px}.last\\:ew-mr-0:last-child{margin-right:0}.last\\:ew-rounded-r-lg:last-child{border-bottom-right-radius:8px;border-top-right-radius:8px}.last\\:ew-rounded-r-\\[16px\\]:last-child{border-bottom-right-radius:16px;border-top-right-radius:16px}.last\\:ew-rounded-r-\\[20px\\]:last-child{border-bottom-right-radius:20px;border-top-right-radius:20px}.focus-within\\:ew-bg-base-aux\\/10:focus-within{background-color:rgb(var(--theme-base-aux-ch)/.1)}.focus-within\\:ew-bg-base-bg:focus-within{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity))}.focus-within\\:ew-text-base-fg:focus-within{--tw-text-opacity:1;color:rgb(var(--theme-base-fg-ch)/var(--tw-text-opacity))}.hover\\:ew-bg-base-aux\\/\\[0\\.07\\]:hover{background-color:rgb(var(--theme-base-aux-ch)/.07)}.hover\\:ew-bg-primary-fg\\/\\[0\\.15\\]:hover{background-color:rgb(var(--theme-primary-fg-ch)/.15)}.hover\\:ew-bg-base-aux\\/10:hover{background-color:rgb(var(--theme-base-aux-ch)/.1)}.hover\\:ew-bg-base-aux\\/\\[0\\.04\\]:hover{background-color:rgb(var(--theme-base-aux-ch)/.04)}.hover\\:before\\:ew-opacity-\\[0\\.07\\]:hover:before{content:var(--tw-content);opacity:.07}.hover\\:before\\:ew-opacity-10:hover:before{content:var(--tw-content);opacity:.1}.hover\\:before\\:ew-opacity-\\[0\\.05\\]:hover:before{content:var(--tw-content);opacity:.05}.focus\\:ew-z-10:focus{z-index:10}.focus\\:ew-bg-base-bg:focus{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity))}.focus\\:ew-bg-base-aux\\/\\[0\\.07\\]:focus{background-color:rgb(var(--theme-base-aux-ch)/.07)}.focus\\:ew-bg-primary-fg\\/\\[0\\.15\\]:focus{background-color:rgb(var(--theme-primary-fg-ch)/.15)}.focus\\:ew-shadow-none:focus{--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.focus\\:ew-outline-none:focus{outline:2px solid transparent;outline-offset:2px}.read-only\\:focus\\:ew-bg-base-aux\\/10:focus:-moz-read-only{background-color:rgb(var(--theme-base-aux-ch)/.1)}.read-only\\:focus\\:ew-bg-base-aux\\/10:focus:read-only{background-color:rgb(var(--theme-base-aux-ch)/.1)}.focus-visible\\:ew-border-primary-fg:focus-visible{--tw-border-opacity:1;border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity))}.focus-visible\\:ew-bg-base-bg:focus-visible{--tw-bg-opacity:1;background-color:rgb(var(--theme-base-bg-ch)/var(--tw-bg-opacity))}.focus-visible\\:ew-outline-0:focus-visible{outline-width:0}.focus-visible\\:ew-ring:focus-visible{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.focus-within\\:focus-visible\\:ew-border-primary-fg:focus-visible:focus-within{--tw-border-opacity:1;border-color:rgb(var(--theme-primary-fg-ch)/var(--tw-border-opacity))}.focus-within\\:focus-visible\\:ew-ring:focus-visible:focus-within{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.active\\:ew-bg-base-aux\\/10:active{background-color:rgb(var(--theme-base-aux-ch)/.1)}.active\\:ew-bg-primary-fg\\/20:active{background-color:rgb(var(--theme-primary-fg-ch)/.2)}.active\\:ew-bg-base-aux\\/\\[0\\.07\\]:active{background-color:rgb(var(--theme-base-aux-ch)/.07)}.active\\:before\\:ew-opacity-\\[0\\.15\\]:active:before{content:var(--tw-content);opacity:.15}.active\\:before\\:ew-opacity-20:active:before{content:var(--tw-content);opacity:.2}.active\\:before\\:ew-opacity-\\[0\\.03\\]:active:before{content:var(--tw-content);opacity:.03}.active\\:before\\:ew-opacity-10:active:before{content:var(--tw-content);opacity:.1}.disabled\\:ew-pointer-events-none:disabled{pointer-events:none}.disabled\\:ew-border-base-aux\\/\\[0\\.25\\]:disabled{border-color:rgb(var(--theme-base-aux-ch)/.25)}.disabled\\:ew-bg-base-aux\\/\\[0\\.25\\]:disabled{background-color:rgb(var(--theme-base-aux-ch)/.25)}.disabled\\:ew-opacity-60:disabled{opacity:.6}.ew-group:focus-within .group-focus-within\\:ew-relative{position:relative}.ew-group:focus-within .group-focus-within\\:ew-rounded{border-radius:4px}.ew-group\\/ew:focus-within .group-focus-within\\/ew\\:ew-border-base-fg{--tw-border-opacity:1;border-color:rgb(var(--theme-base-fg-ch)/var(--tw-border-opacity))}.ew-group:focus-within .group-focus-within\\:ew-bg-neutral-bg{--tw-bg-opacity:1;background-color:rgb(var(--theme-neutral-bg-ch)/var(--tw-bg-opacity))}.ew-group:focus-within .group-focus-within\\:ew-px-2{padding-left:.5rem;padding-right:.5rem}.ew-group:focus-within .group-focus-within\\:ew-text-sm{font-size:.875rem;line-height:1.25rem}.ew-group:focus-within .group-focus-within\\:ew-leading-relaxed{line-height:1.625}.ew-group:focus-within .group-focus-within\\:ew-text-neutral-aux{--tw-text-opacity:1;color:rgb(var(--theme-neutral-aux-ch)/var(--tw-text-opacity))}.ew-group:hover .group-hover\\:ew-translate-y-0{--tw-translate-y:0px}.ew-group:hover .group-hover\\:ew-translate-x-0,.ew-group:hover .group-hover\\:ew-translate-y-0{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.ew-group:hover .group-hover\\:ew-translate-x-0{--tw-translate-x:0px}.ew-group:hover .group-hover\\:ew-opacity-100{opacity:1}.ew-group:hover .group-hover\\:ew-delay-100{transition-delay:.1s}.ew-group:hover .group-hover\\:ew-delay-500{transition-delay:.5s}.ew-group:hover .group-hover\\:ew-delay-1000{transition-delay:1s}@media (min-width:1024px){.lg\\:ew-table-cell{display:table-cell}.lg\\:ew-flex-row{flex-direction:row}.lg\\:ew-flex-col{flex-direction:column}.lg\\:ew-items-start{align-items:flex-start}.lg\\:ew-items-end{align-items:flex-end}.lg\\:ew-items-center{align-items:center}.lg\\:ew-justify-start{justify-content:flex-start}.lg\\:ew-justify-end{justify-content:flex-end}.lg\\:ew-justify-center{justify-content:center}.lg\\:ew-justify-between{justify-content:space-between}.lg\\:ew-justify-around{justify-content:space-around}.lg\\:ew-gap-0{gap:0}.lg\\:ew-gap-1{gap:.25rem}.lg\\:ew-gap-2{gap:.5rem}.lg\\:ew-gap-4{gap:1rem}.lg\\:ew-gap-6{gap:1.5rem}.lg\\:ew-gap-8{gap:2rem}.lg\\:ew-gap-12{gap:3rem}.lg\\:ew-gap-16{gap:4rem}.lg\\:ew-p-0{padding:0}.lg\\:ew-p-1{padding:.25rem}.lg\\:ew-p-2{padding:.5rem}.lg\\:ew-p-4{padding:1rem}.lg\\:ew-p-6{padding:1.5rem}.lg\\:ew-p-8{padding:2rem}.lg\\:ew-p-12{padding:3rem}.lg\\:ew-p-16{padding:4rem}.lg\\:ew-px-0{padding-left:0;padding-right:0}.lg\\:ew-px-1{padding-left:.25rem;padding-right:.25rem}.lg\\:ew-px-2{padding-left:.5rem;padding-right:.5rem}.lg\\:ew-px-4{padding-left:1rem;padding-right:1rem}.lg\\:ew-px-6{padding-left:1.5rem;padding-right:1.5rem}.lg\\:ew-px-8{padding-left:2rem;padding-right:2rem}.lg\\:ew-px-12{padding-left:3rem;padding-right:3rem}.lg\\:ew-px-16{padding-left:4rem;padding-right:4rem}.lg\\:ew-py-0{padding-bottom:0;padding-top:0}.lg\\:ew-py-1{padding-bottom:.25rem;padding-top:.25rem}.lg\\:ew-py-2{padding-bottom:.5rem;padding-top:.5rem}.lg\\:ew-py-4{padding-bottom:1rem;padding-top:1rem}.lg\\:ew-py-6{padding-bottom:1.5rem;padding-top:1.5rem}.lg\\:ew-py-8{padding-bottom:2rem;padding-top:2rem}.lg\\:ew-py-12{padding-bottom:3rem;padding-top:3rem}.lg\\:ew-py-16{padding-bottom:4rem;padding-top:4rem}.lg\\:ew-pt-0{padding-top:0}.lg\\:ew-pt-1{padding-top:.25rem}.lg\\:ew-pt-2{padding-top:.5rem}.lg\\:ew-pt-4{padding-top:1rem}.lg\\:ew-pt-6{padding-top:1.5rem}.lg\\:ew-pt-8{padding-top:2rem}.lg\\:ew-pt-12{padding-top:3rem}.lg\\:ew-pt-16{padding-top:4rem}.lg\\:ew-pl-0{padding-left:0}.lg\\:ew-pl-1{padding-left:.25rem}.lg\\:ew-pl-2{padding-left:.5rem}.lg\\:ew-pl-4{padding-left:1rem}.lg\\:ew-pl-6{padding-left:1.5rem}.lg\\:ew-pl-8{padding-left:2rem}.lg\\:ew-pl-12{padding-left:3rem}.lg\\:ew-pl-16{padding-left:4rem}.lg\\:ew-pr-0{padding-right:0}.lg\\:ew-pr-1{padding-right:.25rem}.lg\\:ew-pr-2{padding-right:.5rem}.lg\\:ew-pr-4{padding-right:1rem}.lg\\:ew-pr-6{padding-right:1.5rem}.lg\\:ew-pr-8{padding-right:2rem}.lg\\:ew-pr-12{padding-right:3rem}.lg\\:ew-pr-16{padding-right:4rem}}""" ]
